# -*- coding: utf-8 -*-
"""Orangetool params."""

ORANGETOOL_VERSION = "0.50"
UPDATE_URL = "http://www.orangetool.ir/version"
IP_PATTERN = r"(?:[0-9]{1,3}\.){3}[0-9]{1,3}"
GLOBAL_IP_API_1 = "http://ipinfo.io/ip"
GENERAL_ERROR_MESSAGE = "Error"
ROOT_ERROR_MESSAGE = "Root Error"
